@@ -63,7 +63,7 @@ class DBConnect():
             logging.warning(str_data)
             abort(Response(str_data, 500, {}))
 
-    def find_docu(self, id: str, raise_err=True) -> dict:
+    def find_docu_by_id(self, id: str, raise_err=True) -> dict:
         """
         根据id查找记录
         :param id:记录id
@@ -88,7 +88,7 @@ class DBConnect():
         entity['_id'] = str(entity['_id'])
         return dict(entity)
 
-    def find_docu_list(self, id_list: list) -> list:
+    def find_docu_by_id_list(self, id_list: list) -> list:
         """
         根据id列表查找记录列表
         :param id_list:
@@ -176,10 +176,7 @@ class DBConnect():
         else:
             find_data.limit(page_size).skip(page_size * current)
         # 处理返回数据
-        query_result = []
-        for data in find_data:
-            data['_id'] = str(data['_id'])
-            query_result.append(data)
+        query_result = handle_db_to_list(find_data)
         return {
             'records_total': self.mongo_collection.estimated_document_count(),
             'records_filtered': records_filtered,
