@@ -1,4 +1,5 @@
 import logging
+import time
 from datetime import datetime, timedelta
 from pymongo.cursor import Cursor
 from bson.objectid import ObjectId
@@ -40,6 +41,8 @@ def handle_db_to_list(db_cursor: Cursor) -> list:
     result = []
     for db in db_cursor:
         db['_id'] = str(db['_id'])
+        db['creation_time'] = int(time.mktime(
+            db['creation_time'].timetuple())) * 1000
         result.append(dict(db))
     return result
 
